@@ -29,7 +29,8 @@ class AutoEncryptionOpts(object):
     """Options to configure automatic client-side field level encryption."""
 
     def __init__(self, kms_providers, key_vault_namespace,
-                 key_vault_client=None, schema_map=None,
+                 key_vault_client=None,
+                 schema_map=None,
                  bypass_auto_encryption=False,
                  mongocryptd_uri='mongodb://localhost:27020',
                  mongocryptd_bypass_spawn=False,
@@ -58,7 +59,8 @@ class AutoEncryptionOpts(object):
 
               - `aws`: Map with "accessKeyId" and "secretAccessKey" as strings.
                 These are the AWS access key ID and AWS secret access key used
-                to generate KMS messages.
+                to generate KMS messages. An optional "sessionToken" may be
+                included to support temporary AWS credentials.
               - `azure`: Map with "tenantId", "clientId", and "clientSecret" as
                 strings. Additionally, "identityPlatformEndpoint" may also be
                 specified as a string (defaults to 'login.microsoftonline.com').
